@@ -34,7 +34,7 @@ def test_fetchChainInfo_UniqueChains_3():
 def test_fetchChainInfo_SimilarChains():
     sim = SimilarChains(pdb='1j85', chain='A')
     assert str(
-        sim.get()) == "[('1J85', 'A'), ('3E5Y', 'A'), ('3N4J', 'A'), ('3N4K', 'A'), ('4JAK', 'A'), ('4JAL', 'A'), ('4KDZ', 'A'), ('4KGN', 'A'), ('4PZK', 'A'), ('5CO4', 'A'), ('6AHW', 'A'), ('6QH8', 'A'), ('6QKV', 'A')]"
+        sim.get()) == "[('1J85', 'A'), ('3E5Y', 'A'), ('3N4J', 'A'), ('3N4K', 'A'), ('4JAK', 'A'), ('4JAL', 'A'), ('4KDZ', 'A'), ('4KGN', 'A'), ('4PZK', 'A'), ('5CO4', 'A'), ('6AHW', 'A'), ('6QH8', 'A'), ('6QKV', 'A'), ('7D51', 'A')]"
     sim = SimilarChains('6lt7', 'A', identity=30)
     assert len(sim.get()) >= 3
     sim = SimilarChains(pdb='7css', chain='A')
@@ -64,10 +64,10 @@ def test_fetchChainInfo_ReleasedProteins():
 def test_fetchChainInfo_ReleasedProteins_2():
     from_date = "2020-11-18"
     res = ReleasedPDBs(from_date).get()
-    assert len(res) == 490
+    assert len(res) == 489
     assert str(res).startswith(
         "[('6hpj', 'B'), ('6kml', 'A'), ('6kml', 'B'), ('6kmq', 'A'), ('6kmq', 'B'), ('6l9k', 'A'), ('6l9k', 'Q'), ('6l9l', 'A'), ('6l9l', 'B'), ('6l9l', 'C'),")
     res = ReleasedPDBs(from_date, only_rna=True).get()
     assert str(res) == "[('6hpj', 'A'), ('6vem', 'A'), ('6wbr', 'B'), ('6wc0', 'B'), ('6wvj', 'R')]"
     res = ReleasedPDBs(from_date, only_rna=False, only_prot=False).get()
-    assert len(res) == 495
+    assert len(res) == 494
